@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -28,6 +28,7 @@ package java.lang;
 import java.io.PrintStream;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Map;
 import java.util.Optional;
 
 class VersionProps {
@@ -35,11 +36,12 @@ class VersionProps {
     private static final String launcher_name =
         "openjdk";
 
+    // This field is read by HotSpot
     private static final String java_version =
-        "11.0.21";
+        "17.0.4.1";
 
     private static final String java_version_date =
-        "2023-10-17";
+        "2022-08-12";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.21+9";
+        "17.0.4.1+1";
 
     private static final String VERSION_NUMBER =
-        "11.0.21";
+        "17.0.4.1";
+
+    private static final String VERSION_SPECIFICATION =
+        "17";
 
     private static final String VERSION_BUILD =
-        "9";
+        "1";
 
     private static final String VERSION_PRE =
         "";
@@ -64,6 +69,9 @@ class VersionProps {
     private static final boolean isLTS =
         "".startsWith("LTS");
 
+    private static final String CLASSFILE_MAJOR_MINOR =
+        "61.0";
+
     private static final String VENDOR =
         "Eclipse Adoptium";
 
@@ -75,30 +83,38 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "Temurin-11.0.21+9";
+        "Temurin-17.0.4.1+1";
 
     private static String VENDOR_URL_BUG =
         "https://github.com/adoptium/adoptium-support/issues";
 
     // This field is read by HotSpot
+    @SuppressWarnings("unused")
     private static String VENDOR_URL_VM_BUG =
         "https://github.com/adoptium/adoptium-support/issues";
 
-    static {
-        init();
-    }
-
-    public static void init() {
-        System.setProperty("java.version", java_version);
-        System.setProperty("java.version.date", java_version_date);
-        System.setProperty("java.runtime.version", java_runtime_version);
-        System.setProperty("java.runtime.name", java_runtime_name);
+    /**
+     * Initialize system properties using build provided values.
+     *
+     * @param props Map instance in which to insert the properties
+     */
+    public static void init(Map<String, String> props) {
+        props.put("java.version", java_version);
+        props.put("java.version.date", java_version_date);
+        props.put("java.runtime.version", java_runtime_version);
+        props.put("java.runtime.name", java_runtime_name);
         if (!VENDOR_VERSION.isEmpty())
-            System.setProperty("java.vendor.version", VENDOR_VERSION);
+            props.put("java.vendor.version", VENDOR_VERSION);
 
-        System.setProperty("java.vendor", VENDOR);
-        System.setProperty("java.vendor.url", VENDOR_URL);
-        System.setProperty("java.vendor.url.bug", VENDOR_URL_BUG);
+        props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
+
+        props.put("java.specification.version", VERSION_SPECIFICATION);
+        props.put("java.specification.name", "Java Platform API Specification");
+        props.put("java.specification.vendor", "Oracle Corporation");
+
+        props.put("java.vendor", VENDOR);
+        props.put("java.vendor.url", VENDOR_URL);
+        props.put("java.vendor.url.bug", VENDOR_URL_BUG);
     }
 
     private static int parseVersionNumber(String version, int prevIndex, int index) {
